/// <reference types="node" />
import { AsyncLocalStorage } from 'async_hooks';
import { REQUEST_CONTEXT_KEY } from './async-local-storage.constants';
import { ContextStoreProperties } from './async-local-storage.interfaces';
declare type K = keyof ContextStoreProperties;
declare type T = ContextStoreProperties;
export declare type StoreMap = Map<K, T[K]>;
export declare class AsyncLocalStorageService extends Map<K, T[K]> {
    readonly instance: AsyncLocalStorage<StoreMap>;
    private static _instance;
    constructor(instance: AsyncLocalStorage<StoreMap>);
    static get instance(): AsyncLocalStorage<StoreMap>;
    static set instance(value: AsyncLocalStorage<StoreMap> | undefined);
    static get store(): StoreMap;
    static get requestContext(): T[typeof REQUEST_CONTEXT_KEY];
    static set requestContext(value: T[typeof REQUEST_CONTEXT_KEY]);
    static enterWith(value?: StoreMap): void;
    static enter(): void;
    static exit(cb?: () => void): void;
    run<R, TArgs extends any[]>(store: StoreMap, callback: (...args: TArgs) => R, ...args: TArgs): R;
    enterWith(value?: StoreMap): void;
    enter(): void;
    exit(cb?: () => void): void;
    get store(): StoreMap | undefined;
    private isStoreInitialized;
    private checkStoreInitialized;
    private get safeStore();
    get<k extends K>(key: k): T[k] | undefined;
    set<k extends K>(key: k, value: T[k]): this;
    delete(key: K): boolean;
    has(key: K): boolean;
    clear(): void;
    get size(): number;
    get [Symbol.toStringTag](): string;
    keys(): IterableIterator<K>;
    values(): IterableIterator<T[keyof T]>;
    entries(): IterableIterator<[K, T[K]]>;
    forEach(callbackfn: (value: T[K], key: K, map: Map<K, T[K]>) => void, thisArg?: any): void;
    [Symbol.iterator](): IterableIterator<[K, T[K]]>;
    get requestContext(): T[typeof REQUEST_CONTEXT_KEY];
    set requestContext(value: T[typeof REQUEST_CONTEXT_KEY]);
}
export {};
